@@ -109,11 +109,8 @@ impl Log for XLog {
     fn flush(&self) {}
 }
 
-// #[macro_export]
-// macro_rules! info {
-//     ($($arg:tt)*) => {
-//         log::info!($($arg)*);
-//     };
-// }
+pub fn init() {
+    XLog::new().init().unwrap();
+}
 
 pub use log::{trace, debug, info, warn, error};
\ No newline at end of file
